==> jbizmo-commons-2.6.0-sources.jar: net/sourceforge/jbizmo/commons/search/dto/SearchListDTO.java <==
/*
 * This file is part of JBizMo, a set of tools, libraries and plug-ins
 * for modeling and creating Java-based enterprise applications.
 * For more information visit:
 *
 * http://sourceforge.net/projects/jbizmo/
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.sourceforge.jbizmo.commons.search.dto;

import java.io.Serializable;

/**
 * <p>
 * Data transfer object for search objects
 * </p>
 * <p>
 * Copyright 2010 (C) by Martin Ganserer
 * </p>
 * @author Martin Ganserer
 * @version 1.0.0
 */
public class SearchListDTO implements Serializable
{
	private static final long serialVersionUID = 3902898068627658318L;
	private int id;
	private String name;
	private String viewName;
	private String userName;

	/**
	 * Constructor
	 * @param id
	 * @param name
	 * @param viewName
	 */
	public SearchListDTO(int id, String name, String viewName)
	{
		this.id = id;
		this.name = name;
		this.viewName = viewName;
	}

	/**
	 * @return the id
	 */
	public int getId()
	{
		return id;
	}

	/**
	 * @param id the id to set
	 */
	public void setId(int id)
	{
		this.id = id;
	}

	/**
	 * @return the name
	 */
	public String getName()
	{
		return name;
	}

	/**
	 * @param name the name to set
	 */
	public void setName(String name)
	{
		this.name = name;
	}

	/**
	 * @return the name of the view
	 */
	public String getViewName()
	{
		return viewName;
	}

	/**
	 * @param viewName the view name to set
	 */
	public void setViewName(String viewName)
	{
		this.viewName = viewName;
	}

	/**
	 * @return the user name
	 */
	public String getUserName()
	{
		return userName;
	}

	/**
	 * @param userName
	 */
	public void setUserName(String userName)
	{
		this.userName = userName;
	}

	/*
	 * (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		result = prime * result + ((userName == null) ? 0 : userName.hashCode());
		result = prime * result + ((viewName == null) ? 0 : viewName.hashCode());
		return result;
	}

	/*
	 * (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if(this == obj)
			return true;

		if(obj == null)
			return false;

		if(getClass() != obj.getClass())
			return false;

		final SearchListDTO other = (SearchListDTO) obj;

		if(name == null)
		{
			if(other.name != null)
				return false;
		}
		else if(!name.equals(other.name))
			return false;

		if(userName == null)
		{
			if(other.userName != null)
				return false;
		}
		else if(!userName.equals(other.userName))
			return false;

		if(viewName == null)
		{
			if(other.viewName != null)
				return false;
		}
		else if(!viewName.equals(other.viewName))
			return false;

		return true;
	}

}

==> jbizmo-commons-6.1.0-sources.jar: net/sourceforge/jbizmo/commons/search/dto/SearchListDTO.java <==
/*
 * This file is part of JBizMo, a set of tools, libraries and plug-ins
 * for modeling and creating Java-based enterprise applications.
 * For more information visit:
 *
 * http://sourceforge.net/projects/jbizmo/
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package net.sourceforge.jbizmo.commons.search.dto;

import java.io.Serializable;

/**
 * <p>
 * Data transfer object for search objects
 * </p>
 * <p>
 * Copyright 2010 (C) by Martin Ganserer
 * </p>
 * @author Martin Ganserer
 * @version 1.0.0
 */
public class SearchListDTO implements Serializable
{
	private static final long serialVersionUID = 3902898068627658318L;

	private int id;
	private String name;
	private String viewName;
	private String userName;

	/**
	 * Constructor
	 * @param id
	 * @param name
	 * @param viewName
	 */
	public SearchListDTO(int id, String name, String viewName)
	{
		this.id = id;
		this.name = name;
		this.viewName = viewName;
	}

	/**
	 * @return the ID
	 */
	public int getId()
	{
		return id;
	}

	/**
	 * @param id the id to set
	 */
	public void setId(int id)
	{
		this.id = id;
	}

	/**
	 * @return the name
	 */
	public String getName()
	{
		return name;
	}

	/**
	 * @param name the name to set
	 */
	public void setName(String name)
	{
		this.name = name;
	}

	/**
	 * @return the name of the view
	 */
	public String getViewName()
	{
		return viewName;
	}

	/**
	 * @param viewName the view name to set
	 */
	public void setViewName(String viewName)
	{
		this.viewName = viewName;
	}

	/**
	 * @return the user name
	 */
	public String getUserName()
	{
		return userName;
	}

	/**
	 * @param userName
	 */
	public void setUserName(String userName)
	{
		this.userName = userName;
	}

	/*
	 * (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((name == null) ? 0 : name.hashCode());
		result = prime * result + ((userName == null) ? 0 : userName.hashCode());
		result = prime * result + ((viewName == null) ? 0 : viewName.hashCode());
		return result;
	}

	/*
	 * (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if(this == obj)
			return true;

		if(obj == null)
			return false;

		if(getClass() != obj.getClass())
			return false;

		final var other = (SearchListDTO) obj;

		if(name == null)
		{
			if(other.name != null)
				return false;
		}
		else if(!name.equals(other.name))
			return false;

		if(userName == null)
		{
			if(other.userName != null)
				return false;
		}
		else if(!userName.equals(other.userName))
			return false;

		if(viewName == null)
		{
			if(other.viewName != null)
				return false;
		}
		else if(!viewName.equals(other.viewName))
			return false;

		return true;
	}

}
